# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/application/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.application import application_config_pb2 as prodvana_dot_application_dot_application__config__pb2
from prodvana.proto.prodvana.application import user_metadata_pb2 as prodvana_dot_application_dot_user__metadata__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/application/object.proto\x12\x14prodvana.application\x1a-prodvana/application/application_config.proto\x1a(prodvana/application/user_metadata.proto\x1a\x1aprodvana/object/meta.proto\"5\n\x10\x41pplicationStateJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\nis_defaultR\tis_legacy\"\xee\x01\n\x0b\x41pplication\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x37\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\'.prodvana.application.ApplicationConfig\x12\x35\n\x05state\x18\x03 \x01(\x0b\x32&.prodvana.application.ApplicationState\x12\x44\n\ruser_metadata\x18\x04 \x01(\x0b\x32-.prodvana.application.ApplicationUserMetadataBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/applicationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.application.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/application'
  _globals['_APPLICATIONSTATE']._serialized_start=176
  _globals['_APPLICATIONSTATE']._serialized_end=229
  _globals['_APPLICATION']._serialized_start=232
  _globals['_APPLICATION']._serialized_end=470
# @@protoc_insertion_point(module_scope)
