# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.common_config import meta_pb2 as prodvana_dot_common__config_dot_meta__pb2
from prodvana.proto.prodvana.convergence import convergence_mode_pb2 as prodvana_dot_convergence_dot_convergence__mode__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.service import user_metadata_pb2 as prodvana_dot_service_dot_user__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/service/object.proto\x12\x10prodvana.service\x1a\x1aprodvana/object/meta.proto\x1a!prodvana/common_config/meta.proto\x1a+prodvana/convergence/convergence_mode.proto\x1a%prodvana/service/service_config.proto\x1a$prodvana/service/user_metadata.proto\"~\n#ServiceInstanceProtectionAttachment\x12\x12\n\nprotection\x18\x01 \x01(\t\x12\x12\n\nattachment\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65sired_state_id\x18\x03 \x01(\t\x12\x15\n\rattachment_id\x18\x04 \x01(\t\"\x9a\x01\n\x0c\x45xternalAddr\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.prodvana.service.ExternalAddr.Type\"I\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\x12\n\n\x06RAW_IP\x10\x03\x12\x10\n\x0cRAW_HOSTNAME\x10\x04\"y\n\x0cServiceState\x12?\n\x10\x63onvergence_mode\x18\x03 \x01(\x0e\x32%.prodvana.convergence.ConvergenceModeJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\x15ongoing_pipeline_runsR\x05state\"\xd2\x01\n\x07Service\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12/\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12-\n\x05state\x18\x03 \x01(\x0b\x32\x1e.prodvana.service.ServiceState\x12<\n\ruser_metadata\x18\x04 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadata\"\xb1\x03\n\x14ServiceInstanceState\x12\x36\n\x0e\x65xternal_addrs\x18\x07 \x03(\x0b\x32\x1e.prodvana.service.ExternalAddr\x12U\n\x16protection_attachments\x18\r \x03(\x0b\x32\x35.prodvana.service.ServiceInstanceProtectionAttachmentJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rR\x05stateR\x0e\x61vailable_podsR\x0c\x64\x65sired_podsR\x1flatest_successful_prodvana_pushR2latest_successful_unknown_push_after_prodvana_pushR\x0congoing_pushR\x04podsR\nruntime_idR\x0cruntime_nameR\x10writeback_configR\x0e\x64\x65livery_state\"\xca\x01\n\x0fServiceInstance\x12?\n\x04meta\x18\x01 \x01(\x0b\x32\x31.prodvana.common_config.ServiceInstanceObjectMeta\x12?\n\x06\x63onfig\x18\x02 \x01(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\x12\x35\n\x05state\x18\x03 \x01(\x0b\x32&.prodvana.service.ServiceInstanceStateBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.service.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _globals['_SERVICEINSTANCEPROTECTIONATTACHMENT']._serialized_start=236
  _globals['_SERVICEINSTANCEPROTECTIONATTACHMENT']._serialized_end=362
  _globals['_EXTERNALADDR']._serialized_start=365
  _globals['_EXTERNALADDR']._serialized_end=519
  _globals['_EXTERNALADDR_TYPE']._serialized_start=446
  _globals['_EXTERNALADDR_TYPE']._serialized_end=519
  _globals['_SERVICESTATE']._serialized_start=521
  _globals['_SERVICESTATE']._serialized_end=642
  _globals['_SERVICE']._serialized_start=645
  _globals['_SERVICE']._serialized_end=855
  _globals['_SERVICEINSTANCESTATE']._serialized_start=858
  _globals['_SERVICEINSTANCESTATE']._serialized_end=1291
  _globals['_SERVICEINSTANCE']._serialized_start=1294
  _globals['_SERVICEINSTANCE']._serialized_end=1496
# @@protoc_insertion_point(module_scope)
