"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import prodvana.proto.prodvana.object.meta_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServiceInstanceObjectMeta(google.protobuf.message.Message):
    """oneoff meta definitions stored here to allow referencing without import cycles

    HACK(naphat) service instances do not have their own id and names today
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_META_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_META_FIELD_NUMBER: builtins.int
    @property
    def service_meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta:
        """These metas will only have versions set if service instance has been pushed before"""
    @property
    def release_channel_meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    def __init__(
        self,
        *,
        service_meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        release_channel_meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release_channel_meta", b"release_channel_meta", "service_meta", b"service_meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release_channel_meta", b"release_channel_meta", "service_meta", b"service_meta"]) -> None: ...

global___ServiceInstanceObjectMeta = ServiceInstanceObjectMeta

class PipelineRunObjectMeta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_META_FIELD_NUMBER: builtins.int
    RUN_NAME_FIELD_NUMBER: builtins.int
    @property
    def pipeline_meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    run_name: builtins.str
    def __init__(
        self,
        *,
        pipeline_meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        run_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline_meta", b"pipeline_meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_meta", b"pipeline_meta", "run_name", b"run_name"]) -> None: ...

global___PipelineRunObjectMeta = PipelineRunObjectMeta
