# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery/delivery_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/delivery/delivery_config.proto\x12\x11prodvana.delivery\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\"_\n\x0e\x43\x61naryProgress\x12 \n\rcanary_weight\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x64(\x00\x12+\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"h\n\x0e\x44\x65liveryConfig\x12:\n\x0f\x63\x61nary_progress\x18\x01 \x03(\x0b\x32!.prodvana.delivery.CanaryProgress\x12\x1a\n\x12\x61nalysis_templates\x18\x02 \x03(\tBMZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/deliveryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.delivery.delivery_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery'
  _CANARYPROGRESS.fields_by_name['canary_weight']._options = None
  _CANARYPROGRESS.fields_by_name['canary_weight']._serialized_options = b'\372B\006\032\004\030d(\000'
  _globals['_CANARYPROGRESS']._serialized_start=119
  _globals['_CANARYPROGRESS']._serialized_end=214
  _globals['_DELIVERYCONFIG']._serialized_start=216
  _globals['_DELIVERYCONFIG']._serialized_end=320
# @@protoc_insertion_point(module_scope)
