# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/meta.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/meta.proto\x12\x16prodvana.common_config\x1a\x1aprodvana/object/meta.proto\"\x89\x01\n\x19ServiceInstanceObjectMeta\x12\x31\n\x0cservice_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x39\n\x14release_channel_meta\x18\x02 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"]\n\x15PipelineRunObjectMeta\x12\x32\n\rpipeline_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x10\n\x08run_name\x18\x02 \x01(\tBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.meta_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _globals['_SERVICEINSTANCEOBJECTMETA']._serialized_start=90
  _globals['_SERVICEINSTANCEOBJECTMETA']._serialized_end=227
  _globals['_PIPELINERUNOBJECTMETA']._serialized_start=229
  _globals['_PIPELINERUNOBJECTMETA']._serialized_end=322
# @@protoc_insertion_point(module_scope)
