# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pipelines/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.common_config import meta_pb2 as prodvana_dot_common__config_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fprodvana/pipelines/object.proto\x12\x12prodvana.pipelines\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!prodvana/common_config/meta.proto\"\xa6\x01\n\x10PipelineRunState\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05state\x18\x03 \x01(\t\x12\x10\n\x08terminal\x18\x04 \x01(\x08\"\x7f\n\x0bPipelineRun\x12;\n\x04meta\x18\x01 \x01(\x0b\x32-.prodvana.common_config.PipelineRunObjectMeta\x12\x33\n\x05state\x18\x03 \x01(\x0b\x32$.prodvana.pipelines.PipelineRunStateBNZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelinesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.pipelines.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelines'
  _globals['_PIPELINERUNSTATE']._serialized_start=124
  _globals['_PIPELINERUNSTATE']._serialized_end=290
  _globals['_PIPELINERUN']._serialized_start=292
  _globals['_PIPELINERUN']._serialized_end=419
# @@protoc_insertion_point(module_scope)
