# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/auth/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18prodvana/auth/auth.proto\x12\rprodvana.auth\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1a\n\tAuthToken\x12\r\n\x05token\x18\x01 \x01(\t\"\xa0\x01\n\x0c\x41piTokenInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x35\n\x11\x65xpires_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\\\n\x0b\x41uthContext\x12,\n\nauth_token\x18\x01 \x01(\x0b\x32\x18.prodvana.auth.AuthToken\x12\x11\n\tapi_token\x18\x02 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x03 \x01(\t\"\xfe\x02\n\x07Session\x12\x36\n\x08\x63ontexts\x18\x03 \x03(\x0b\x32$.prodvana.auth.Session.ContextsEntry\x12\x17\n\x0f\x63urrent_context\x18\x04 \x01(\t\x12\x41\n\x0e\x61\x64min_contexts\x18\x05 \x03(\x0b\x32).prodvana.auth.Session.AdminContextsEntry\x12\x1d\n\x15\x63urrent_admin_context\x18\x06 \x01(\t\x1aK\n\rContextsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.prodvana.auth.AuthContext:\x02\x38\x01\x1aP\n\x12\x41\x64minContextsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.prodvana.auth.AuthContext:\x02\x38\x01J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\nauth_tokenR\tapi_tokenBIZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.auth.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/auth'
  _SESSION_CONTEXTSENTRY._options = None
  _SESSION_CONTEXTSENTRY._serialized_options = b'8\001'
  _SESSION_ADMINCONTEXTSENTRY._options = None
  _SESSION_ADMINCONTEXTSENTRY._serialized_options = b'8\001'
  _globals['_AUTHTOKEN']._serialized_start=76
  _globals['_AUTHTOKEN']._serialized_end=102
  _globals['_APITOKENINFO']._serialized_start=105
  _globals['_APITOKENINFO']._serialized_end=265
  _globals['_AUTHCONTEXT']._serialized_start=267
  _globals['_AUTHCONTEXT']._serialized_end=359
  _globals['_SESSION']._serialized_start=362
  _globals['_SESSION']._serialized_end=744
  _globals['_SESSION_CONTEXTSENTRY']._serialized_start=552
  _globals['_SESSION_CONTEXTSENTRY']._serialized_end=627
  _globals['_SESSION_ADMINCONTEXTSENTRY']._serialized_start=629
  _globals['_SESSION_ADMINCONTEXTSENTRY']._serialized_end=709
# @@protoc_insertion_point(module_scope)
