# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/metrics/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/metrics/metrics.proto\x12\x10prodvana.metrics\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x08\n\x11\x44\x65ploymentMetrics\x12:\n\x06values\x18\x01 \x01(\x0b\x32*.prodvana.metrics.DeploymentMetrics.Values\x12I\n\ntimeseries\x18\x02 \x03(\x0b\x32\x35.prodvana.metrics.DeploymentMetrics.TimeseriesMetrics\x12:\n\x06\x64\x65ltas\x18\x03 \x01(\x0b\x32*.prodvana.metrics.DeploymentMetrics.Deltas\x1a\xbb\x02\n\x06\x44\x65ltas\x12\x19\n\x11total_deployments\x18\x01 \x01(\x01\x12\x1e\n\x16successful_deployments\x18\x02 \x01(\x01\x12&\n\x1esuccessful_deployments_per_day\x18\x03 \x01(\x01\x12\x1a\n\x12\x66\x61iled_deployments\x18\x04 \x01(\x01\x12-\n%median_successful_deployment_duration\x18\x05 \x01(\x01\x12\x1f\n\x17\x64\x65ployment_failure_rate\x18\x06 \x01(\x01\x12\x17\n\x0ftotal_rollbacks\x18\x07 \x01(\x01\x12\x1c\n\x14successful_rollbacks\x18\x08 \x01(\x01\x12+\n#median_successful_rollback_duration\x18\t \x01(\x01\x1a\xc1\x03\n\x06Values\x12\x19\n\x11total_deployments\x18\x01 \x01(\x01\x12\x1e\n\x16successful_deployments\x18\x02 \x01(\x01\x12&\n\x1esuccessful_deployments_per_day\x18\x03 \x01(\x01\x12\x1a\n\x12\x66\x61iled_deployments\x18\x04 \x01(\x01\x12H\n%median_successful_deployment_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x17\x64\x65ployment_failure_rate\x18\x06 \x01(\x01\x12\x17\n\x0ftotal_rollbacks\x18\x07 \x01(\x01\x12\x1c\n\x14successful_rollbacks\x18\x08 \x01(\x01\x12\x46\n#median_successful_rollback_duration\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12N\n*last_successful_deployment_completion_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a~\n\x11TimeseriesMetrics\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16successful_deployments\x18\x02 \x01(\x01\x12\x1a\n\x12\x66\x61iled_deployments\x18\x03 \x01(\x01\"(\n\x04\x43ost\x12\x12\n\nconfigured\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ost\x18\x02 \x01(\x02\x42LZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/metricsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.metrics.metrics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/metrics'
  _globals['_DEPLOYMENTMETRICS']._serialized_start=118
  _globals['_DEPLOYMENTMETRICS']._serialized_end=1230
  _globals['_DEPLOYMENTMETRICS_DELTAS']._serialized_start=335
  _globals['_DEPLOYMENTMETRICS_DELTAS']._serialized_end=650
  _globals['_DEPLOYMENTMETRICS_VALUES']._serialized_start=653
  _globals['_DEPLOYMENTMETRICS_VALUES']._serialized_end=1102
  _globals['_DEPLOYMENTMETRICS_TIMESERIESMETRICS']._serialized_start=1104
  _globals['_DEPLOYMENTMETRICS_TIMESERIESMETRICS']._serialized_end=1230
  _globals['_COST']._serialized_start=1232
  _globals['_COST']._serialized_end=1272
# @@protoc_insertion_point(module_scope)
