# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.repo import repo_pb2 as prodvana_dot_repo_dot_repo__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/release/object.proto\x12\x10prodvana.release\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1aprodvana/object/meta.proto\x1a\x18prodvana/repo/repo.proto\x1a\x17validate/validate.proto\"\xfa\x01\n\rReleaseConfig\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x11\x64\x65ployment_system\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x0b\x61pplication\x18\x08 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\nrepository\x18\x05 \x01(\t\x12\x11\n\tcommit_id\x18\x06 \x01(\t\x12\x0c\n\x04user\x18\x07 \x01(\t\"z\n\x0cReleaseState\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"g\n\x18ImpactAnalysisComparison\x12/\n\x10relevant_commits\x18\x01 \x03(\x0b\x32\x15.prodvana.repo.Commit\x12\x1a\n\x12unanalyzed_commits\x18\x02 \x01(\x03\"\x97\x02\n\x11ReleaseComparison\x12)\n\x04prev\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x17\n\x0fprev_repository\x18\x02 \x01(\t\x12\x16\n\x0enew_repository\x18\x03 \x01(\t\x12\x16\n\x0eprev_commit_id\x18\x04 \x01(\t\x12\x15\n\rnew_commit_id\x18\x05 \x01(\t\x12\x43\n\x0fimpact_analysis\x18\x06 \x01(\x0b\x32*.prodvana.release.ImpactAnalysisComparison\x12\x32\n\rtotal_commits\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xcd\x01\n\x07Release\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12/\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfig\x12\x37\n\ncomparison\x18\x03 \x01(\x0b\x32#.prodvana.release.ReleaseComparison\x12-\n\x05state\x18\x04 \x01(\x0b\x32\x1e.prodvana.release.ReleaseState*K\n\rReleaseStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x42LZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/releaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release'
  _RELEASECONFIG.fields_by_name['deployment_system']._options = None
  _RELEASECONFIG.fields_by_name['deployment_system']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECONFIG.fields_by_name['service']._options = None
  _RELEASECONFIG.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECONFIG.fields_by_name['release_channel']._options = None
  _RELEASECONFIG.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECONFIG.fields_by_name['application']._options = None
  _RELEASECONFIG.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RELEASESTATUS']._serialized_start=1167
  _globals['_RELEASESTATUS']._serialized_end=1242
  _globals['_RELEASECONFIG']._serialized_start=196
  _globals['_RELEASECONFIG']._serialized_end=446
  _globals['_RELEASESTATE']._serialized_start=448
  _globals['_RELEASESTATE']._serialized_end=570
  _globals['_IMPACTANALYSISCOMPARISON']._serialized_start=572
  _globals['_IMPACTANALYSISCOMPARISON']._serialized_end=675
  _globals['_RELEASECOMPARISON']._serialized_start=678
  _globals['_RELEASECOMPARISON']._serialized_end=957
  _globals['_RELEASE']._serialized_start=960
  _globals['_RELEASE']._serialized_end=1165
# @@protoc_insertion_point(module_scope)
