# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/environment/environment_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/environment/environment_manager.proto\x12\x14prodvana.environment\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#prodvana/environment/clusters.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"3\n\x1aGetClusterAgentApiTokenReq\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"0\n\x1bGetClusterAgentApiTokenResp\x12\x11\n\tapi_token\x18\x01 \x01(\t\"\xde\x02\n\x0eLinkClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04\x61uth\x18\x02 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x12/\n\x04type\x18\x06 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12\x33\n\x06\x63onfig\x18\t \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12(\n\x06source\x18\x07 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x08 \x01(\x0b\x32 .prodvana.version.SourceMetadataJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x10prodvana_managedR\rdisable_istioR\x0f\x64isable_flagger\"\xa8\x01\n\x0fLinkClusterResp\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x15\n\rk8s_agent_url\x18\x04 \x01(\t\x12\x17\n\x0fk8s_agent_image\x18\x05 \x01(\t\x12\x16\n\x0ek8s_agent_args\x18\x06 \x03(\t\x12\x1b\n\x13k8s_agent_api_token\x18\x07 \x01(\t\" \n\x10RemoveClusterReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x13\n\x11RemoveClusterResp\"\'\n\x11GetClusterAuthReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"E\n\x12GetClusterAuthResp\x12/\n\x04\x61uth\x18\x01 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\"\x11\n\x0fListClustersReq\"\xab\x04\n\x10ListClustersResp\x12\x44\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x32.prodvana.environment.ListClustersResp.ClusterInfo\x1a\xd0\x03\n\x0b\x43lusterInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\x12/\n\x04type\x18\x07 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12I\n\x03\x65\x63s\x18\x08 \x01(\x0b\x32:.prodvana.environment.ListClustersResp.ClusterInfo.EcsInfoH\x00\x12<\n\x18last_heartbeat_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x06\x63onfig\x18\n \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12/\n\x04\x61uth\x18\x0b \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x1a.\n\x07\x45\x63sInfo\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x13\n\x0b\x63luster_arn\x18\x02 \x01(\tB\x06\n\x04infoJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07R\x06originR\x10writeback_config\"6\n\rGetClusterReq\x12\x0f\n\x07runtime\x18\x01 \x01(\t\x12\x14\n\x0cinclude_auth\x18\x02 \x01(\x08\"U\n\x0eGetClusterResp\x12\x43\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x32.prodvana.environment.ListClustersResp.ClusterInfo\"\xc5\x01\n\x13\x43onfigureClusterReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"\x16\n\x14\x43onfigureClusterResp\"\x97\x01\n\x1cValidateConfigureClusterResp\x12\x39\n\x0cinput_config\x18\x01 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12<\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\"+\n\x13GetClusterConfigReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\"K\n\x14GetClusterConfigResp\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\".\n\x16\x44\x65tectClusterConfigReq\x12\x14\n\x0cruntime_name\x18\x01 \x01(\t\"N\n\x17\x44\x65tectClusterConfigResp\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\")\n\x13GetClusterStatusReq\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"T\n\x14GetClusterStatusResp\x12<\n\x18last_heartbeat_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\"\n\x0fPauseClusterReq\x12\x0f\n\x07runtime\x18\x01 \x01(\t\"\x12\n\x10PauseClusterResp\"#\n\x10ResumeClusterReq\x12\x0f\n\x07runtime\x18\x01 \x01(\t\"\x13\n\x11ResumeClusterResp2\xc4\x0e\n\x12\x45nvironmentManager\x12\xa3\x01\n\x17GetClusterAgentApiToken\x12\x30.prodvana.environment.GetClusterAgentApiTokenReq\x1a\x31.prodvana.environment.GetClusterAgentApiTokenResp\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/clusters/{name=*}/token\x12x\n\x0bLinkCluster\x12$.prodvana.environment.LinkClusterReq\x1a%.prodvana.environment.LinkClusterResp\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/clusters/link:\x01*\x12x\n\x0cListClusters\x12%.prodvana.environment.ListClustersReq\x1a&.prodvana.environment.ListClustersResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/clusters/list\x12}\n\nGetCluster\x12#.prodvana.environment.GetClusterReq\x1a$.prodvana.environment.GetClusterResp\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/clusters/{runtime=*}/get\x12\x80\x01\n\rRemoveCluster\x12&.prodvana.environment.RemoveClusterReq\x1a\'.prodvana.environment.RemoveClusterResp\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/clusters/remove:\x01*\x12\x82\x01\n\x0eGetClusterAuth\x12\'.prodvana.environment.GetClusterAuthReq\x1a(.prodvana.environment.GetClusterAuthResp\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/clusters/get_auth\x12\x9a\x01\n\x10GetClusterConfig\x12).prodvana.environment.GetClusterConfigReq\x1a*.prodvana.environment.GetClusterConfigResp\"/\x82\xd3\xe4\x93\x02)\"$/v1/clusters/{runtime_name=*}/config:\x01*\x12\xaa\x01\n\x13\x44\x65tectClusterConfig\x12,.prodvana.environment.DetectClusterConfigReq\x1a-.prodvana.environment.DetectClusterConfigResp\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/clusters/{runtime_name=*}/detect-config:\x01*\x12\x8c\x01\n\x10\x43onfigureCluster\x12).prodvana.environment.ConfigureClusterReq\x1a*.prodvana.environment.ConfigureClusterResp\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/clusters/configure:\x01*\x12\xa5\x01\n\x18ValidateConfigureCluster\x12).prodvana.environment.ConfigureClusterReq\x1a\x32.prodvana.environment.ValidateConfigureClusterResp\"*\x82\xd3\xe4\x93\x02$\"\x1f/v1/clusters/configure/validate:\x01*\x12\x8a\x01\n\x10GetClusterStatus\x12).prodvana.environment.GetClusterStatusReq\x1a*.prodvana.environment.GetClusterStatusResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/clusters/get_status\x12|\n\x0cPauseCluster\x12%.prodvana.environment.PauseClusterReq\x1a&.prodvana.environment.PauseClusterResp\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/clusters/pause:\x01*\x12\x80\x01\n\rResumeCluster\x12&.prodvana.environment.ResumeClusterReq\x1a\'.prodvana.environment.ResumeClusterResp\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/clusters/resume:\x01*BPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environmentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.environment.environment_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environment'
  _GETCLUSTERAGENTAPITOKENREQ.fields_by_name['name']._options = None
  _GETCLUSTERAGENTAPITOKENREQ.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAgentApiToken']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAgentApiToken']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/clusters/{name=*}/token'
  _ENVIRONMENTMANAGER.methods_by_name['LinkCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['LinkCluster']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/clusters/link:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ListClusters']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ListClusters']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/clusters/list'
  _ENVIRONMENTMANAGER.methods_by_name['GetCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetCluster']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/clusters/{runtime=*}/get'
  _ENVIRONMENTMANAGER.methods_by_name['RemoveCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['RemoveCluster']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/clusters/remove:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAuth']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterAuth']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/clusters/get_auth'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterConfig']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterConfig']._serialized_options = b'\202\323\344\223\002)\"$/v1/clusters/{runtime_name=*}/config:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['DetectClusterConfig']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['DetectClusterConfig']._serialized_options = b'\202\323\344\223\0020\"+/v1/clusters/{runtime_name=*}/detect-config:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ConfigureCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ConfigureCluster']._serialized_options = b'\202\323\344\223\002\033\"\026/v1/clusters/configure:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ValidateConfigureCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ValidateConfigureCluster']._serialized_options = b'\202\323\344\223\002$\"\037/v1/clusters/configure/validate:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterStatus']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['GetClusterStatus']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/clusters/get_status'
  _ENVIRONMENTMANAGER.methods_by_name['PauseCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['PauseCluster']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/clusters/pause:\001*'
  _ENVIRONMENTMANAGER.methods_by_name['ResumeCluster']._options = None
  _ENVIRONMENTMANAGER.methods_by_name['ResumeCluster']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/clusters/resume:\001*'
  _globals['_GETCLUSTERAGENTAPITOKENREQ']._serialized_start=237
  _globals['_GETCLUSTERAGENTAPITOKENREQ']._serialized_end=288
  _globals['_GETCLUSTERAGENTAPITOKENRESP']._serialized_start=290
  _globals['_GETCLUSTERAGENTAPITOKENRESP']._serialized_end=338
  _globals['_LINKCLUSTERREQ']._serialized_start=341
  _globals['_LINKCLUSTERREQ']._serialized_end=691
  _globals['_LINKCLUSTERRESP']._serialized_start=694
  _globals['_LINKCLUSTERRESP']._serialized_end=862
  _globals['_REMOVECLUSTERREQ']._serialized_start=864
  _globals['_REMOVECLUSTERREQ']._serialized_end=896
  _globals['_REMOVECLUSTERRESP']._serialized_start=898
  _globals['_REMOVECLUSTERRESP']._serialized_end=917
  _globals['_GETCLUSTERAUTHREQ']._serialized_start=919
  _globals['_GETCLUSTERAUTHREQ']._serialized_end=958
  _globals['_GETCLUSTERAUTHRESP']._serialized_start=960
  _globals['_GETCLUSTERAUTHRESP']._serialized_end=1029
  _globals['_LISTCLUSTERSREQ']._serialized_start=1031
  _globals['_LISTCLUSTERSREQ']._serialized_end=1048
  _globals['_LISTCLUSTERSRESP']._serialized_start=1051
  _globals['_LISTCLUSTERSRESP']._serialized_end=1606
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO']._serialized_start=1142
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO']._serialized_end=1606
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO']._serialized_start=1514
  _globals['_LISTCLUSTERSRESP_CLUSTERINFO_ECSINFO']._serialized_end=1560
  _globals['_GETCLUSTERREQ']._serialized_start=1608
  _globals['_GETCLUSTERREQ']._serialized_end=1662
  _globals['_GETCLUSTERRESP']._serialized_start=1664
  _globals['_GETCLUSTERRESP']._serialized_end=1749
  _globals['_CONFIGURECLUSTERREQ']._serialized_start=1752
  _globals['_CONFIGURECLUSTERREQ']._serialized_end=1949
  _globals['_CONFIGURECLUSTERRESP']._serialized_start=1951
  _globals['_CONFIGURECLUSTERRESP']._serialized_end=1973
  _globals['_VALIDATECONFIGURECLUSTERRESP']._serialized_start=1976
  _globals['_VALIDATECONFIGURECLUSTERRESP']._serialized_end=2127
  _globals['_GETCLUSTERCONFIGREQ']._serialized_start=2129
  _globals['_GETCLUSTERCONFIGREQ']._serialized_end=2172
  _globals['_GETCLUSTERCONFIGRESP']._serialized_start=2174
  _globals['_GETCLUSTERCONFIGRESP']._serialized_end=2249
  _globals['_DETECTCLUSTERCONFIGREQ']._serialized_start=2251
  _globals['_DETECTCLUSTERCONFIGREQ']._serialized_end=2297
  _globals['_DETECTCLUSTERCONFIGRESP']._serialized_start=2299
  _globals['_DETECTCLUSTERCONFIGRESP']._serialized_end=2377
  _globals['_GETCLUSTERSTATUSREQ']._serialized_start=2379
  _globals['_GETCLUSTERSTATUSREQ']._serialized_end=2420
  _globals['_GETCLUSTERSTATUSRESP']._serialized_start=2422
  _globals['_GETCLUSTERSTATUSRESP']._serialized_end=2506
  _globals['_PAUSECLUSTERREQ']._serialized_start=2508
  _globals['_PAUSECLUSTERREQ']._serialized_end=2542
  _globals['_PAUSECLUSTERRESP']._serialized_start=2544
  _globals['_PAUSECLUSTERRESP']._serialized_end=2562
  _globals['_RESUMECLUSTERREQ']._serialized_start=2564
  _globals['_RESUMECLUSTERREQ']._serialized_end=2599
  _globals['_RESUMECLUSTERRESP']._serialized_start=2601
  _globals['_RESUMECLUSTERRESP']._serialized_end=2620
  _globals['_ENVIRONMENTMANAGER']._serialized_start=2623
  _globals['_ENVIRONMENTMANAGER']._serialized_end=4483
# @@protoc_insertion_point(module_scope)
