# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/workflow/integration_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*prodvana/workflow/integration_config.proto\x12\x11prodvana.workflow\x1a\x17validate/validate.proto\"w\n\x0e\x41lertingConfig\x12>\n\tpagerduty\x18\x01 \x01(\x0b\x32+.prodvana.workflow.AlertingConfig.PagerDuty\x1a%\n\tPagerDuty\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x92\x01\n\x11\x41nnotationsConfig\x12\x41\n\thoneycomb\x18\x01 \x01(\x0b\x32..prodvana.workflow.AnnotationsConfig.Honeycomb\x1a:\n\tHoneycomb\x12\x1c\n\x0b\x65nvironment\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07\x64\x61taset\x18\x02 \x01(\t\"E\n\x0bTokenConfig\x12\x18\n\x10token_secret_key\x18\x01 \x01(\t\x12\x1c\n\x14token_secret_version\x18\x02 \x01(\t\"\xa2\x01\n\x11IntegrationConfig\x12\x36\n\x0cslack_config\x18\x01 \x01(\x0b\x32\x1e.prodvana.workflow.TokenConfigH\x00\x12:\n\x10pagerduty_config\x18\x02 \x01(\x0b\x32\x1e.prodvana.workflow.TokenConfigH\x00\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04\x42MZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/workflowb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.workflow.integration_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/workflow'
  _ALERTINGCONFIG_PAGERDUTY.fields_by_name['service']._options = None
  _ALERTINGCONFIG_PAGERDUTY.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _ANNOTATIONSCONFIG_HONEYCOMB.fields_by_name['environment']._options = None
  _ANNOTATIONSCONFIG_HONEYCOMB.fields_by_name['environment']._serialized_options = b'\372B\004r\002\020\001'
  _INTEGRATIONCONFIG.oneofs_by_name['config_oneof']._options = None
  _INTEGRATIONCONFIG.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _globals['_ALERTINGCONFIG']._serialized_start=90
  _globals['_ALERTINGCONFIG']._serialized_end=209
  _globals['_ALERTINGCONFIG_PAGERDUTY']._serialized_start=172
  _globals['_ALERTINGCONFIG_PAGERDUTY']._serialized_end=209
  _globals['_ANNOTATIONSCONFIG']._serialized_start=212
  _globals['_ANNOTATIONSCONFIG']._serialized_end=358
  _globals['_ANNOTATIONSCONFIG_HONEYCOMB']._serialized_start=300
  _globals['_ANNOTATIONSCONFIG_HONEYCOMB']._serialized_end=358
  _globals['_TOKENCONFIG']._serialized_start=360
  _globals['_TOKENCONFIG']._serialized_end=429
  _globals['_INTEGRATIONCONFIG']._serialized_start=432
  _globals['_INTEGRATIONCONFIG']._serialized_end=594
# @@protoc_insertion_point(module_scope)
