# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/convergence/convergence_mode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+prodvana/convergence/convergence_mode.proto\x12\x14prodvana.convergence*:\n\x0f\x43onvergenceMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x43ONVERGE\x10\x01\x12\x0c\n\x08OBSERVER\x10\x02\x42PZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/convergenceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.convergence.convergence_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/convergence'
  _globals['_CONVERGENCEMODE']._serialized_start=69
  _globals['_CONVERGENCEMODE']._serialized_end=127
# @@protoc_insertion_point(module_scope)
