"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.delivery_extension.config_pb2
import prodvana.proto.prodvana.delivery_extension.object_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureDeliveryExtensionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def delivery_extension_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        delivery_extension_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_extension_config", b"delivery_extension_config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension_config", b"delivery_extension_config", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureDeliveryExtensionReq = ConfigureDeliveryExtensionReq

class ConfigureDeliveryExtensionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_extension_id: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        delivery_extension_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension_id", b"delivery_extension_id", "version", b"version"]) -> None: ...

global___ConfigureDeliveryExtensionResp = ConfigureDeliveryExtensionResp

class ValidateConfigureDeliveryExtensionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> None: ...

global___ValidateConfigureDeliveryExtensionResp = ValidateConfigureDeliveryExtensionResp

class ListDeliveryExtensionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDeliveryExtensionsReq = ListDeliveryExtensionsReq

class ListDeliveryExtensionsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def delivery_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        delivery_extensions: collections.abc.Iterable[prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extensions", b"delivery_extensions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDeliveryExtensionsResp = ListDeliveryExtensionsResp

class GetDeliveryExtensionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_FIELD_NUMBER: builtins.int
    delivery_extension: builtins.str
    def __init__(
        self,
        *,
        delivery_extension: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension"]) -> None: ...

global___GetDeliveryExtensionReq = GetDeliveryExtensionReq

class GetDeliveryExtensionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_FIELD_NUMBER: builtins.int
    @property
    def delivery_extension(self) -> prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension: ...
    def __init__(
        self,
        *,
        delivery_extension: prodvana.proto.prodvana.delivery_extension.object_pb2.DeliveryExtension | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension"]) -> None: ...

global___GetDeliveryExtensionResp = GetDeliveryExtensionResp

class GetDeliveryExtensionConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_extension: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        delivery_extension: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension", b"delivery_extension", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionConfigReq = GetDeliveryExtensionConfigReq

class GetDeliveryExtensionConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig: ...
    version: builtins.str
    """next tag: 4"""
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionConfigResp = GetDeliveryExtensionConfigResp

class GetDeliveryExtensionInstanceConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_EXTENSION_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_extension_instance_id: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        delivery_extension_instance_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_extension_instance_id", b"delivery_extension_instance_id", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionInstanceConfigReq = GetDeliveryExtensionInstanceConfigReq

class GetDeliveryExtensionInstanceConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.CompiledDeliveryExtensionInstanceConfig: ...
    version: builtins.str
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.delivery_extension.config_pb2.CompiledDeliveryExtensionInstanceConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "version", b"version"]) -> None: ...

global___GetDeliveryExtensionInstanceConfigResp = GetDeliveryExtensionInstanceConfigResp
