# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pvn_wrapper/output.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/pvn_wrapper/output.proto\x12\x14prodvana.pvn_wrapper\"\xd2\x01\n\x06Output\x12\x11\n\texit_code\x18\x01 \x01(\x05\x12\x12\n\nexec_error\x18\x02 \x01(\t\x12\x16\n\x0estdout_blob_id\x18\x03 \x01(\t\x12\x16\n\x0estderr_blob_id\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x1a\n\x12start_timestamp_ns\x18\x06 \x01(\x03\x12\x13\n\x0b\x64uration_ns\x18\x07 \x01(\x03\x12/\n\x05\x66iles\x18\x08 \x03(\x0b\x32 .prodvana.pvn_wrapper.OutputFile\"3\n\nOutputFile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x63ontent_blob_id\x18\x02 \x01(\tBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pvn_wrapperb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.pvn_wrapper.output_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pvn_wrapper'
  _globals['_OUTPUT']._serialized_start=60
  _globals['_OUTPUT']._serialized_end=270
  _globals['_OUTPUTFILE']._serialized_start=272
  _globals['_OUTPUTFILE']._serialized_end=323
# @@protoc_insertion_point(module_scope)
