"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EnvValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    RAW_SECRET_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    KUBERNETES_SECRET_FIELD_NUMBER: builtins.int
    value: builtins.str
    raw_secret: builtins.str
    """Raw secret value to be used for user-editable YAML and RPC calls."""
    @property
    def secret(self) -> global___Secret:
        """Externally stored secret."""
    @property
    def kubernetes_secret(self) -> global___KubernetesSecret:
        """Kubernetes secret, only works for Kubernetes runtimes."""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        raw_secret: builtins.str = ...,
        secret: global___Secret | None = ...,
        kubernetes_secret: global___KubernetesSecret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kubernetes_secret", b"kubernetes_secret", "raw_secret", b"raw_secret", "secret", b"secret", "value", b"value", "value_oneof", b"value_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kubernetes_secret", b"kubernetes_secret", "raw_secret", b"raw_secret", "secret", b"secret", "value", b"value", "value_oneof", b"value_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value_oneof", b"value_oneof"]) -> typing_extensions.Literal["value", "raw_secret", "secret", "kubernetes_secret"] | None: ...

global___EnvValue = EnvValue

class Secret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    key: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "version", b"version"]) -> None: ...

global___Secret = Secret

class KubernetesSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_NAME_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    secret_name: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        secret_name: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "secret_name", b"secret_name"]) -> None: ...

global___KubernetesSecret = KubernetesSecret
