"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CanaryProgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CANARY_WEIGHT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    canary_weight: builtins.int
    """weight to advance canary to, percentage 0-100"""
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """duration to pause at this weight before advancing"""
    def __init__(
        self,
        *,
        canary_weight: builtins.int = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["canary_weight", b"canary_weight", "duration", b"duration"]) -> None: ...

global___CanaryProgress = CanaryProgress

class DeliveryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CANARY_PROGRESS_FIELD_NUMBER: builtins.int
    ANALYSIS_TEMPLATES_FIELD_NUMBER: builtins.int
    @property
    def canary_progress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CanaryProgress]:
        """progression of canary as delivery occurs"""
    @property
    def analysis_templates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        canary_progress: collections.abc.Iterable[global___CanaryProgress] | None = ...,
        analysis_templates: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["analysis_templates", b"analysis_templates", "canary_progress", b"canary_progress"]) -> None: ...

global___DeliveryConfig = DeliveryConfig
